@@ -22,7 +22,9 @@ import json
 import urllib
 
 def _download(args):
-	"""Downloads the json response and returns it"""
+	"""
+		Downloads the json response and returns it
+	"""
 	
 	base = "http://lyricwiki.org/mw_api.php?"
 	args = urllib.urlencode(args)
@@ -30,7 +32,9 @@ def _download(args):
 	return urllib.urlopen(base + args).read()
 
 def _search(keywords):
-	"""Returns the first hit's title page"""
+	"""
+		Returns the first hit's title page
+	"""
 	
 	args = {"action": "query",
 		"list": "search",
@@ -56,14 +60,21 @@ def _get_lyrics(page_title):
 	content = json.loads(_download(args))["query"]["pages"].popitem()[1]["revisions"][0]["*"]
 	if "<lyrics>" in content:
 		return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
-	
-def get_lyrics(*keywords):
-	"""Search for and return lyrics
-	keywords should include the title and artist
-	example:
-	lyrics = get_lyrics("iron maiden", "fear of the dark")"""
+
+def search_for_lyrics(*keywords):
+	"""
+		Search for and return lyrics
+		keywords should include the title and artist
+	"""
 	title = _search(" ".join(keywords))
 	if not title:
 		return
 	
 	return _get_lyrics(title)
+
+def get_lyrics(artist, title):
+	"""
+		Get lyrics by artist and title
+	"""
+	
+	return _get_lyrics("%s:%s" %(artist.title(), title.title()))
